<?php 

add_action( 'customize_register', 'b3_ghost_customize_register' );

function b3_ghost_customize_register($wp_customize){


	class Customize_Pages_Control extends WP_Customize_Control {
	
	   
		public $type = 'checkbox-multiple-pages';
	
		public function enqueue() {
			wp_enqueue_script( 'b3_ghost_page_selector', trailingslashit( get_stylesheet_directory_uri() ) . 'js/b3_ghost_page_selector.js', array( 'jquery' ) );
		}
	
		public function render_content() {
	
			if ( empty( $this->choices ) )
				return; ?>
	
			<?php if ( !empty( $this->label ) ) : ?>
				<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
			<?php endif; ?>
	
			<?php if ( !empty( $this->description ) ) : ?>
				<span class="description customize-control-description"><?php echo $this->description; ?></span>
			<?php endif; ?>
	
			<?php $multi_values = !is_array( $this->value() ) ? explode( ',', $this->value() ) : $this->value(); ?>
	
			<ul>
				<?php foreach ( $this->choices as $value => $label ) : ?>

					<li>
						<label>
							<input type="checkbox" value="<?php echo esc_attr( $value ); ?>" <?php checked( in_array( $value, $multi_values ) ); ?> /> 
							<?php echo esc_html( $label ); ?>
						</label>
					</li>

				<?php endforeach; ?>
			</ul>
	
			<input type="hidden" <?php $this->link(); ?> value="<?php echo esc_attr( implode( ',', $multi_values ) ); ?>" />
		<?php }
	}		

 
	$wp_customize->add_section( 'et_b3_ghost_header' , array(
		'title'       => esc_html__( 'Ghost Header', 'Divi' ),
		'priority'    => 2,
	) );
	
	
	
	$wp_customize->add_setting( 'et_divi[color_primary]', array(
		'default'		=> '#cda568',
		'type'			=> 'option',
		'capability'	=> 'edit_theme_options',
		'transport'		=> 'postMessage',
		 
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( 
		$wp_customize, 
		'et_divi[color_primary]', 
		array(
			'label'      => __( 'Primary Color', '' ),
			'section'    => 'et_color_schemes',
			'settings'   => 'et_divi[color_primary]',
		        'priority'   => 1
		)
	));	


	$wp_customize->add_setting( 'et_divi[ghost_header]', array(
		'default'		=> true,
		'type'			=> 'option',
		'capability'	=> 'edit_theme_options',
		'transport'		=> 'postMessage',
		'sanitize_callback' => 'wp_validate_boolean',
	) );
	
	$wp_customize->add_control( 'et_divi[ghost_header]', array(
		'label'		=> esc_html__( 'Ghost Header', '' ),
		'section'	=> 'et_b3_ghost_header',
		'type'      => 'checkbox',
	) );
	
	
	$wp_customize->add_setting('et_divi[ghost_header_logo]', array(
        'type' => 'option',
        'capability' => 'edit_theme_options',
    ));
	
    $wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'et_divi[ghost_header_logo]', array(
        'label' => __('Ghost Header Logo', ''),
        'section' => 'et_b3_ghost_header',
        'settings' => 'et_divi[ghost_header_logo]',
    )));
	
	
	$wp_customize->add_setting('et_divi[fixed_ghost_header_logo]', array(
        'type' => 'option',
        'capability' => 'edit_theme_options',
    ));
	
    $wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'et_divi[fixed_ghost_header_logo]', array(
        'label' => __('Fixed Ghost Header Logo', ''),
        'section' => 'et_b3_ghost_header',
        'settings' => 'et_divi[fixed_ghost_header_logo]',
    )));
	
	
	
	
	$wp_customize->add_setting( 'et_divi[ghost_primary_nav_bg]', array(
		'default'		=> '#f7af11',
		'type'			=> 'option',
		'capability'	=> 'edit_theme_options',
		'transport'		=> 'postMessage',
		'sanitize_callback' => 'et_sanitize_alpha_color',
	) );

	$wp_customize->add_control( new ET_Divi_Customize_Color_Alpha_Control( $wp_customize, 'et_divi[ghost_primary_nav_bg]', array(
		'label'		=> esc_html__( 'Ghost Header Background Color', 'Divi' ),
		'section'	=> 'et_b3_ghost_header',
		'settings'	=> 'et_divi[ghost_primary_nav_bg]',
	) ) );
	
	$wp_customize->add_setting( 'et_divi[ghost_fixed_primary_nav_bg]', array(
			'default'		=>  '#ffffff' ,
			'type'			=> 'option',
			'capability'	=> 'edit_theme_options',
			'transport'		=> 'postMessage',
			'sanitize_callback' => 'et_sanitize_alpha_color',
		) );

	$wp_customize->add_control( new ET_Divi_Customize_Color_Alpha_Control( $wp_customize, 'et_divi[ghost_fixed_primary_nav_bg]', array(
		'label'		=> esc_html__( 'Fixed Header Background Color', 'Divi' ),
		'section'	=> 'et_b3_ghost_header',
		'settings'	=> 'et_divi[ghost_fixed_primary_nav_bg]',
	) ) );
	
	
	
	
	$wp_customize->add_setting( 'et_divi[ghost_df_text_color]', array(
		'default'		=> '#ffffff',
		'type'			=> 'option',
		'capability'	=> 'edit_theme_options',
		'transport'		=> 'postMessage',
		'sanitize_callback' => 'et_sanitize_alpha_color',
	) );

	$wp_customize->add_control( new ET_Divi_Customize_Color_Alpha_Control( $wp_customize, 'et_divi[ghost_df_text_color]', array(
		'label'		=> esc_html__( 'Ghost Header Text Color', 'Divi' ),
		'section'	=> 'et_b3_ghost_header',
		'settings'	=> 'et_divi[ghost_df_text_color]',
	) ) );
	
	$wp_customize->add_setting( 'et_divi[ghost_fx_text_color]', array(
			'default'		=>  '#697986' ,
			'type'			=> 'option',
			'capability'	=> 'edit_theme_options',
			'transport'		=> 'postMessage',
			'sanitize_callback' => 'et_sanitize_alpha_color',
		) );

	$wp_customize->add_control( new ET_Divi_Customize_Color_Alpha_Control( $wp_customize, 'et_divi[ghost_fx_text_color]', array(
		'label'		=> esc_html__( 'Fixed Header Text Color', 'Divi' ),
		'section'	=> 'et_b3_ghost_header',
		'settings'	=> 'et_divi[ghost_fx_text_color]',
	) ) );
	
	
	
	
	
	$wp_customize->add_setting( 'et_divi[ghost_df_active_link_text_color]', array(
		'default'		=> '#FFFFFF',
		'type'			=> 'option',
		'capability'	=> 'edit_theme_options',
		'transport'		=> 'postMessage',
		'sanitize_callback' => 'et_sanitize_alpha_color',
	) );

	$wp_customize->add_control( new ET_Divi_Customize_Color_Alpha_Control( $wp_customize, 'et_divi[ghost_df_active_link_text_color]', array(
		'label'		=> esc_html__( 'Ghost Header Active Link Text Color', 'Divi' ),
		'section'	=> 'et_b3_ghost_header',
		'settings'	=> 'et_divi[ghost_df_active_link_text_color]',
	) ) );
	
	$wp_customize->add_setting( 'et_divi[ghost_fx_active_link_text_color]', array(
			'default'		=>  '#697986' ,
			'type'			=> 'option',
			'capability'	=> 'edit_theme_options',
			'transport'		=> 'postMessage',
			'sanitize_callback' => 'et_sanitize_alpha_color',
		) );

	$wp_customize->add_control( new ET_Divi_Customize_Color_Alpha_Control( $wp_customize, 'et_divi[ghost_fx_active_link_text_color]', array(
		'label'		=> esc_html__( 'Fixed Header Active Link Text Color', 'Divi' ),
		'section'	=> 'et_b3_ghost_header',
		'settings'	=> 'et_divi[ghost_fx_active_link_text_color]',
	) ) );
	
	
	
	
	$wp_customize->add_setting( 'et_divi[ghost_dropdown_menu_nav_bg]', array(
		'default'		=> '#FFFFFF',
		'type'			=> 'option',
		'capability'	=> 'edit_theme_options',
		'transport'		=> 'postMessage',
		'sanitize_callback' => 'et_sanitize_alpha_color',
	) );

	$wp_customize->add_control( new ET_Divi_Customize_Color_Alpha_Control( $wp_customize, 'et_divi[ghost_dropdown_menu_nav_bg]', array(
		'label'		=> esc_html__( 'Dropdown Menu Background Color', 'Divi' ),
		'section'	=> 'et_b3_ghost_header',
		'settings'	=> 'et_divi[ghost_dropdown_menu_nav_bg]',
	) ) );
	
	$wp_customize->add_setting( 'et_divi[ghost_dropdown_line_nav_bg]', array(
			'default'		=>  '#40D188' ,
			'type'			=> 'option',
			'capability'	=> 'edit_theme_options',
			'transport'		=> 'postMessage',
			'sanitize_callback' => 'et_sanitize_alpha_color',
		) );

	$wp_customize->add_control( new ET_Divi_Customize_Color_Alpha_Control( $wp_customize, 'et_divi[ghost_dropdown_line_nav_bg]', array(
		'label'		=> esc_html__( 'Dropdown Menu Line Color', 'Divi' ),
		'section'	=> 'et_b3_ghost_header',
		'settings'	=> 'et_divi[ghost_dropdown_line_nav_bg]',
	) ) );
	
	$wp_customize->add_setting( 'et_divi[ghost_dropdown_text_nav_bg]', array(
			'default'		=>  '#697986' ,
			'type'			=> 'option',
			'capability'	=> 'edit_theme_options',
			'transport'		=> 'postMessage',
			'sanitize_callback' => 'et_sanitize_alpha_color',
		) );

	$wp_customize->add_control( new ET_Divi_Customize_Color_Alpha_Control( $wp_customize, 'et_divi[ghost_dropdown_text_nav_bg]', array(
		'label'		=> esc_html__( 'Dropdown Menu Text Color', 'Divi' ),
		'section'	=> 'et_b3_ghost_header',
		'settings'	=> 'et_divi[ghost_dropdown_text_nav_bg]',
	) ) );
	
	 // ADD SETTING & CONTROL for pages
	 
	 $pages = get_pages(); 
	 //$ghost_selected_pages = array("all"=>"Whole Site");
	 foreach ($pages as $page) {
			$ghost_selected_pages[$page->ID]=  $page->post_title;
	 }
	 $exclude_array = array('page','attachment','revision','nav_menu_item','custom_css','customize_changeset','et_pb_layout');
	 foreach(get_post_types() as $pt) {
	 	 
		 if ( !in_array($pt,$exclude_array) ){
		 		$ghost_selected_pages[$pt]=  ucwords($pt." archive & detail page");
		 }
	 } 
	
	$exclude_array_taxo = array('nav_menu','link_category','scope','module_width','layout_type','layout_category','et_pb_layout');

	
	 foreach(get_taxonomies() as $taxonomies) {
	 	
		if ( !in_array($taxonomies,$exclude_array_taxo) ){
		 		$ghost_selected_pages[$taxonomies]=  ucwords(str_replace( '_' , ' ' , $taxonomies ) );
		 }
		 
	 } 
	 $ghost_selected_pages['authorp']=  'Author Page';
	 $ghost_selected_pages['searchp']=  'Search Page';
	 $ghost_selected_pages['404p']=  '404 Page';
	 $ghost_selected_pages['datep']=  'Date,Year,Month,Day,Time Page';

	$wp_customize->add_setting(
			'ghost_selected_pages',
			array(
				//'default'           => array( 'all'),
				'capability'	=> 'edit_theme_options',
				'transport'		=> 'postMessage',
			)
	 );

    $wp_customize->add_control(
        new Customize_Pages_Control(
            $wp_customize,
            'ghost_selected_pages',
            array(
                'section' => 'et_b3_ghost_header',
                'label'   => __( 'Ghost Header Display On', '' ),
                'choices' => $ghost_selected_pages
            )
        )
    );
	
}
add_action( 'wp_head', 'b3_ghost_add_customizer_css' );
function b3_ghost_add_customizer_css(){
	global $post, $wp_query;
	
	$post_id = '';
	$post_id = $post->ID;
	if ( $post_id == '' ){
		$post_id = $wp_query->get_queried_object_id();
	}
	$ghost_header_enable = get_post_meta( $post_id, 'ghost_header_enable', true );

	$ghost_header = et_get_option( 'ghost_header', true );
	if ( $ghost_header_enable != "Default" && $ghost_header_enable != '' && $ghost_header == 1  ){
	
			if  ( $ghost_header_enable == "on" && $ghost_header_enable != '' && $ghost_header == 1 ) {
			
				$divi_ghost_df_text_color = et_get_option('ghost_df_text_color','#ffffff');
				$divi_ghost_df_active_link_text_color = et_get_option('ghost_df_active_link_text_color','#FFFFFF');
				$divi_ghost_fx_text_color = et_get_option('ghost_fx_text_color','#697986');
				$divi_ghost_fx_active_link_text_color = et_get_option('ghost_fx_active_link_text_color','#697986');
				
				$divi_ghost_dropdown_menu_nav_bg = et_get_option('ghost_dropdown_menu_nav_bg','#FFFFFF');
				$divi_ghost_dropdown_line_nav_bg = et_get_option('ghost_dropdown_line_nav_bg','#40D188');
				$divi_ghost_dropdown_text_nav_bg = et_get_option('ghost_dropdown_text_nav_bg','#697986');
		
				$color_primary = et_get_option( 'color_primary', '#cda568' );
				$ghost_primary_nav_bg =  et_get_option( 'ghost_primary_nav_bg', '#f7af11' );
				$ghost_fixed_primary_nav_bg = et_get_option( 'ghost_fixed_primary_nav_bg', '#ffffff' );
			
					?>
<style id="ghost-customizer-css">
.normal.menu-item a:before{background-color: <?php echo $color_primary; ?>;}
<?php if($ghost_header): ?>
/*@media only screen and (min-width: 981px){*/
#main-header {background-color: <?php echo $ghost_primary_nav_bg; ?> !important; }		
#main-header.et-fixed-header {background-color: <?php echo $ghost_fixed_primary_nav_bg; ?> !important;}	
		
/*Search Text*/
#main-header .et_search_form_container input{color:<?php echo $divi_ghost_df_text_color; ?> !important;}
#main-header.et-fixed-header .et_search_form_container input{color:<?php echo $divi_ghost_fx_text_color; ?> !important;}
/*Form text color*/
#main-header .et-search-form input.et-search-field::-webkit-input-placeholder{color:<?php echo $divi_ghost_df_text_color; ?> !important;font-weight:500;}
#main-header .et-search-form input.et-search-field::-moz-placeholder{color:<?php echo $divi_ghost_df_text_color; ?> !important;font-weight:500;}
#main-header .et-search-form input.et-search-field:-ms-input-placeholder{ color:<?php echo $divi_ghost_df_text_color; ?> !important;font-weight:500;}
#main-header .et-search-form input.et-search-fieldl:-moz-placeholder{color:<?php echo $divi_ghost_df_text_color; ?> !important;font-weight:500;}

#main-header.et-fixed-header .et-search-form input.et-search-field::-webkit-input-placeholder{color:<?php echo $divi_ghost_fx_text_color; ?> !important;font-weight:500;}
#main-header.et-fixed-header .et-search-form input.et-search-field::-moz-placeholder{color:<?php echo $divi_ghost_fx_text_color; ?> !important;font-weight:500;}
#main-header.et-fixed-header .et-search-form input.et-search-field:-ms-input-placeholder{color:<?php echo $divi_ghost_fx_text_color; ?> !important;font-weight:500;}
#main-header.et-fixed-header .et-search-form input.et-search-fieldl:-moz-placeholder{color:<?php echo $divi_ghost_fx_text_color; ?> !important;font-weight:500;}
					
#main-header ul#top-menu li.menu-item:not(.marvel-menu-cta) a,#et_search_icon:before,span.et_close_search_field:after,#et-top-navigation .et-cart-info{color: <?php echo $divi_ghost_df_text_color; ?> !important; }
#main-header ul#top-menu li.menu-item.current-menu-item:not(.marvel-menu-cta) a{color: <?php echo $divi_ghost_df_active_link_text_color; ?> !important; }
#main-header ul#top-menu li.menu-item.current-menu-ancestor:not(.marvel-menu-cta) > a{color: <?php echo $divi_ghost_df_active_link_text_color; ?> !important; }

#main-header.et-fixed-header ul#top-menu li.menu-item:not(.marvel-menu-cta) a,#main-header.et-fixed-header #et_search_icon:before,#main-header.et-fixed-header span.et_close_search_field:after,#main-header.et-fixed-header #et-top-navigation .et-cart-info{color: <?php echo $divi_ghost_fx_text_color; ?> !important; }
#main-header.et-fixed-header ul#top-menu li.menu-item.current-menu-item:not(.marvel-menu-cta) a{color: <?php echo $divi_ghost_fx_active_link_text_color; ?> !important; }
#main-header.et-fixed-header ul#top-menu li.menu-item.current-menu-ancestor:not(.marvel-menu-cta) > a{color: <?php echo $divi_ghost_fx_active_link_text_color; ?> !important; }

#main-header ul#mobile_menu li.menu-item:not(.marvel-menu-cta) a{color: <?php echo $divi_ghost_df_text_color; ?> !important; }
#main-header ul#mobile_menu li.menu-item.current-menu-item:not(.marvel-menu-cta) a{color: <?php echo $divi_ghost_df_active_link_text_color; ?> !important; }
#main-header ul#mobile_menu li.menu-item.current-menu-ancestor:not(.marvel-menu-cta) > a{color: <?php echo $divi_ghost_df_active_link_text_color; ?> !important; }

#main-header .nav li ul.sub-menu,#main-header.et-fixed-header .nav li ul.sub-menu { background-color: <?php echo $divi_ghost_dropdown_menu_nav_bg; ?>;border-color:  <?php echo $divi_ghost_dropdown_line_nav_bg; ?>;}
#main-header ul#top-menu li.menu-item:not(.marvel-menu-cta) ul.sub-menu a{ color: <?php echo $divi_ghost_dropdown_text_nav_bg; ?> !important;}
/*}*/
<?php endif; ?>
</style>
				<?php	
			}
	}else{
	
	if ( $ghost_header == 1 ){ 
		$ghost_selected_pages = explode(',',get_theme_mod( 'ghost_selected_pages', 'all' ));
		
		$divi_ghost_df_text_color = et_get_option('ghost_df_text_color','#ffffff');
		$divi_ghost_df_active_link_text_color = et_get_option('ghost_df_active_link_text_color','#FFFFFF');
		$divi_ghost_fx_text_color = et_get_option('ghost_fx_text_color','#697986');
		$divi_ghost_fx_active_link_text_color = et_get_option('ghost_fx_active_link_text_color','#697986');
		
		$divi_ghost_dropdown_menu_nav_bg = et_get_option('ghost_dropdown_menu_nav_bg','#FFFFFF');
		$divi_ghost_dropdown_line_nav_bg = et_get_option('ghost_dropdown_line_nav_bg','#40D188');
		$divi_ghost_dropdown_text_nav_bg = et_get_option('ghost_dropdown_text_nav_bg','#697986');
		
		if( in_array( $post_id , $ghost_selected_pages ) && !is_404() ){ 
		    $color_primary = et_get_option( 'color_primary', '#cda568' );
			$ghost_primary_nav_bg =  et_get_option( 'ghost_primary_nav_bg', '#f7af11' );
			$ghost_fixed_primary_nav_bg = et_get_option( 'ghost_fixed_primary_nav_bg', '#ffffff' );
			?>
<style id="ghost-customizer-css">
.normal.menu-item a:before{background-color: <?php echo $color_primary; ?>;}
<?php if($ghost_header): ?>
/*@media only screen and (min-width: 981px){*/
#main-header {background-color: <?php echo $ghost_primary_nav_bg; ?> !important; }		
#main-header.et-fixed-header {background-color: <?php echo $ghost_fixed_primary_nav_bg; ?> !important;}	

/*Search Text*/
#main-header .et_search_form_container input{color:<?php echo $divi_ghost_df_text_color; ?> !important;}
#main-header.et-fixed-header .et_search_form_container input{color:<?php echo $divi_ghost_fx_text_color; ?> !important;}
/*Form text color*/
#main-header .et-search-form input.et-search-field::-webkit-input-placeholder{color:<?php echo $divi_ghost_df_text_color; ?> !important;font-weight:500;}
#main-header .et-search-form input.et-search-field::-moz-placeholder{color:<?php echo $divi_ghost_df_text_color; ?> !important;font-weight:500;}
#main-header .et-search-form input.et-search-field:-ms-input-placeholder{ color:<?php echo $divi_ghost_df_text_color; ?> !important;font-weight:500;}
#main-header .et-search-form input.et-search-fieldl:-moz-placeholder{color:<?php echo $divi_ghost_df_text_color; ?> !important;font-weight:500;}

#main-header.et-fixed-header .et-search-form input.et-search-field::-webkit-input-placeholder{color:<?php echo $divi_ghost_fx_text_color; ?> !important;font-weight:500;}
#main-header.et-fixed-header .et-search-form input.et-search-field::-moz-placeholder{color:<?php echo $divi_ghost_fx_text_color; ?> !important;font-weight:500;}
#main-header.et-fixed-header .et-search-form input.et-search-field:-ms-input-placeholder{color:<?php echo $divi_ghost_fx_text_color; ?> !important;font-weight:500;}
#main-header.et-fixed-header .et-search-form input.et-search-fieldl:-moz-placeholder{color:<?php echo $divi_ghost_fx_text_color; ?> !important;font-weight:500;}


#main-header ul#top-menu li.menu-item:not(.marvel-menu-cta) a,#et_search_icon:before,span.et_close_search_field:after,#et-top-navigation .et-cart-info{color: <?php echo $divi_ghost_df_text_color; ?> !important; }
#main-header ul#top-menu li.menu-item.current-menu-item:not(.marvel-menu-cta) a{color: <?php echo $divi_ghost_df_active_link_text_color; ?> !important; }
#main-header ul#top-menu li.menu-item.current-menu-ancestor:not(.marvel-menu-cta) > a{color: <?php echo $divi_ghost_df_active_link_text_color; ?> !important; }

#main-header.et-fixed-header ul#top-menu li.menu-item:not(.marvel-menu-cta) a,#main-header.et-fixed-header #et_search_icon:before,#main-header.et-fixed-header span.et_close_search_field:after,#main-header.et-fixed-header #et-top-navigation .et-cart-info{color: <?php echo $divi_ghost_fx_text_color; ?> !important; }
#main-header.et-fixed-header ul#top-menu li.menu-item.current-menu-item:not(.marvel-menu-cta) a{color: <?php echo $divi_ghost_fx_active_link_text_color; ?> !important; }
#main-header.et-fixed-header ul#top-menu li.menu-item.current-menu-ancestor:not(.marvel-menu-cta) > a{color: <?php echo $divi_ghost_fx_active_link_text_color; ?> !important; }

#main-header ul#mobile_menu li.menu-item:not(.marvel-menu-cta) a{color: <?php echo $divi_ghost_df_text_color; ?> !important; }
#main-header ul#mobile_menu li.menu-item.current-menu-item:not(.marvel-menu-cta) a{color: <?php echo $divi_ghost_df_active_link_text_color; ?> !important; }
#main-header ul#mobile_menu li.menu-item.current-menu-ancestor:not(.marvel-menu-cta) > a{color: <?php echo $divi_ghost_df_active_link_text_color; ?> !important; }

#main-header .nav li ul.sub-menu,#main-header.et-fixed-header .nav li ul.sub-menu { background-color: <?php echo $divi_ghost_dropdown_menu_nav_bg; ?>;border-color:  <?php echo $divi_ghost_dropdown_line_nav_bg; ?>;}
#main-header ul#top-menu li.menu-item:not(.marvel-menu-cta) ul.sub-menu a{ color: <?php echo $divi_ghost_dropdown_text_nav_bg; ?> !important;}


/*}*/
<?php endif; ?>
</style>
		<?php
			
		}
		
		 $exclude_array_check = array('page','attachment','revision','nav_menu_item','custom_css','customize_changeset','et_pb_layout');
		 foreach(get_post_types() as $pt) {
			 
			 if ( !in_array($pt,$exclude_array_check) ){
		
					if( in_array( $pt , $ghost_selected_pages ) ){ 
							
							if ( is_singular( $pt ) || is_post_type_archive( $pt ) ){
								  $color_primary = et_get_option( 'color_primary', '#cda568' );
			$ghost_primary_nav_bg =  et_get_option( 'ghost_primary_nav_bg', '#f7af11' );
			$ghost_fixed_primary_nav_bg = et_get_option( 'ghost_fixed_primary_nav_bg', '#ffffff' );
									?>
<style id="ghost-customizer-css">
.normal.menu-item a:before{background-color: <?php echo $color_primary; ?>;}
<?php if($ghost_header): ?>
/*@media only screen and (min-width: 981px){*/
#main-header {background-color: <?php echo $ghost_primary_nav_bg; ?> !important; }		
#main-header.et-fixed-header {background-color: <?php echo $ghost_fixed_primary_nav_bg; ?> !important;}	

/*Search Text*/
#main-header .et_search_form_container input{color:<?php echo $divi_ghost_df_text_color; ?> !important;}
#main-header.et-fixed-header .et_search_form_container input{color:<?php echo $divi_ghost_fx_text_color; ?> !important;}
/*Form text color*/
#main-header .et-search-form input.et-search-field::-webkit-input-placeholder{color:<?php echo $divi_ghost_df_text_color; ?> !important;font-weight:500;}
#main-header .et-search-form input.et-search-field::-moz-placeholder{color:<?php echo $divi_ghost_df_text_color; ?> !important;font-weight:500;}
#main-header .et-search-form input.et-search-field:-ms-input-placeholder{ color:<?php echo $divi_ghost_df_text_color; ?> !important;font-weight:500;}
#main-header .et-search-form input.et-search-fieldl:-moz-placeholder{color:<?php echo $divi_ghost_df_text_color; ?> !important;font-weight:500;}

#main-header.et-fixed-header .et-search-form input.et-search-field::-webkit-input-placeholder{color:<?php echo $divi_ghost_fx_text_color; ?> !important;font-weight:500;}
#main-header.et-fixed-header .et-search-form input.et-search-field::-moz-placeholder{color:<?php echo $divi_ghost_fx_text_color; ?> !important;font-weight:500;}
#main-header.et-fixed-header .et-search-form input.et-search-field:-ms-input-placeholder{color:<?php echo $divi_ghost_fx_text_color; ?> !important;font-weight:500;}
#main-header.et-fixed-header .et-search-form input.et-search-fieldl:-moz-placeholder{color:<?php echo $divi_ghost_fx_text_color; ?> !important;font-weight:500;}

#main-header ul#top-menu li.menu-item:not(.marvel-menu-cta) a,#et_search_icon:before,span.et_close_search_field:after,#et-top-navigation .et-cart-info{color: <?php echo $divi_ghost_df_text_color; ?> !important; }
#main-header ul#top-menu li.menu-item.current-menu-item:not(.marvel-menu-cta) a{color: <?php echo $divi_ghost_df_active_link_text_color; ?> !important; }
#main-header ul#top-menu li.menu-item.current-menu-ancestor:not(.marvel-menu-cta) > a{color: <?php echo $divi_ghost_df_active_link_text_color; ?> !important; }

#main-header.et-fixed-header ul#top-menu li.menu-item:not(.marvel-menu-cta) a,#main-header.et-fixed-header #et_search_icon:before,#main-header.et-fixed-header span.et_close_search_field:after,#main-header.et-fixed-header #et-top-navigation .et-cart-info{color: <?php echo $divi_ghost_fx_text_color; ?> !important; }
#main-header.et-fixed-header ul#top-menu li.menu-item.current-menu-item:not(.marvel-menu-cta) a{color: <?php echo $divi_ghost_fx_active_link_text_color; ?> !important; }
#main-header.et-fixed-header ul#top-menu li.menu-item.current-menu-ancestor:not(.marvel-menu-cta) > a{color: <?php echo $divi_ghost_fx_active_link_text_color; ?> !important; }

#main-header ul#mobile_menu li.menu-item:not(.marvel-menu-cta) a{color: <?php echo $divi_ghost_df_text_color; ?> !important; }
#main-header ul#mobile_menu li.menu-item.current-menu-item:not(.marvel-menu-cta) a{color: <?php echo $divi_ghost_df_active_link_text_color; ?> !important; }
#main-header ul#mobile_menu li.menu-item.current-menu-ancestor:not(.marvel-menu-cta) > a{color: <?php echo $divi_ghost_df_active_link_text_color; ?> !important; }

#main-header .nav li ul.sub-menu,#main-header.et-fixed-header .nav li ul.sub-menu { background-color: <?php echo $divi_ghost_dropdown_menu_nav_bg; ?>;border-color:  <?php echo $divi_ghost_dropdown_line_nav_bg; ?>;}
#main-header ul#top-menu li.menu-item:not(.marvel-menu-cta) ul.sub-menu a{ color: <?php echo $divi_ghost_dropdown_text_nav_bg; ?> !important;}

/*}*/
<?php endif; ?>
</style>
									<?php
						  }
					}

			 }
		 } 
		 
		 
	     $exclude_array_taxo_check = array('nav_menu','link_category','scope','module_width','layout_type','layout_category','et_pb_layout');
		  foreach(get_taxonomies() as $taxonomies) {
			 
			 if ( !in_array($taxonomies,$exclude_array_taxo_check) ){
					if( in_array( $taxonomies , $ghost_selected_pages ) ){ 
							
							if ( is_tax( $taxonomies  ) || is_tag() || is_category()  ){
								  $color_primary = et_get_option( 'color_primary', '#cda568' );
			$ghost_primary_nav_bg =  et_get_option( 'ghost_primary_nav_bg', '#f7af11' );
			$ghost_fixed_primary_nav_bg = et_get_option( 'ghost_fixed_primary_nav_bg', '#ffffff' );
									?>
<style id="ghost-customizer-css">
.normal.menu-item a:before{background-color: <?php echo $color_primary; ?>;}
<?php if($ghost_header): ?>

#main-header {background-color: <?php echo $ghost_primary_nav_bg; ?> !important; }		
#main-header.et-fixed-header {background-color: <?php echo $ghost_fixed_primary_nav_bg; ?> !important;}	
/*Search Text*/
#main-header .et_search_form_container input{color:<?php echo $divi_ghost_df_text_color; ?> !important;}
#main-header.et-fixed-header .et_search_form_container input{color:<?php echo $divi_ghost_fx_text_color; ?> !important;}
/*Form text color*/
#main-header .et-search-form input.et-search-field::-webkit-input-placeholder{color:<?php echo $divi_ghost_df_text_color; ?> !important;font-weight:500;}
#main-header .et-search-form input.et-search-field::-moz-placeholder{color:<?php echo $divi_ghost_df_text_color; ?> !important;font-weight:500;}
#main-header .et-search-form input.et-search-field:-ms-input-placeholder{ color:<?php echo $divi_ghost_df_text_color; ?> !important;font-weight:500;}
#main-header .et-search-form input.et-search-fieldl:-moz-placeholder{color:<?php echo $divi_ghost_df_text_color; ?> !important;font-weight:500;}

#main-header.et-fixed-header .et-search-form input.et-search-field::-webkit-input-placeholder{color:<?php echo $divi_ghost_fx_text_color; ?> !important;font-weight:500;}
#main-header.et-fixed-header .et-search-form input.et-search-field::-moz-placeholder{color:<?php echo $divi_ghost_fx_text_color; ?> !important;font-weight:500;}
#main-header.et-fixed-header .et-search-form input.et-search-field:-ms-input-placeholder{color:<?php echo $divi_ghost_fx_text_color; ?> !important;font-weight:500;}
#main-header.et-fixed-header .et-search-form input.et-search-fieldl:-moz-placeholder{color:<?php echo $divi_ghost_fx_text_color; ?> !important;font-weight:500;}

#main-header ul#top-menu li.menu-item:not(.marvel-menu-cta) a,#et_search_icon:before,span.et_close_search_field:after,#et-top-navigation .et-cart-info{color: <?php echo $divi_ghost_df_text_color; ?> !important; }
#main-header ul#top-menu li.menu-item.current-menu-item:not(.marvel-menu-cta) a{color: <?php echo $divi_ghost_df_active_link_text_color; ?> !important; }
#main-header ul#top-menu li.menu-item.current-menu-ancestor:not(.marvel-menu-cta) > a{color: <?php echo $divi_ghost_df_active_link_text_color; ?> !important; }

#main-header.et-fixed-header ul#top-menu li.menu-item:not(.marvel-menu-cta) a,#main-header.et-fixed-header #et_search_icon:before,#main-header.et-fixed-header span.et_close_search_field:after,#main-header.et-fixed-header #et-top-navigation .et-cart-info{color: <?php echo $divi_ghost_fx_text_color; ?> !important; }
#main-header.et-fixed-header ul#top-menu li.menu-item.current-menu-item:not(.marvel-menu-cta) a{color: <?php echo $divi_ghost_fx_active_link_text_color; ?> !important; }
#main-header.et-fixed-header ul#top-menu li.menu-item.current-menu-ancestor:not(.marvel-menu-cta) > a{color: <?php echo $divi_ghost_fx_active_link_text_color; ?> !important; }

#main-header ul#mobile_menu li.menu-item:not(.marvel-menu-cta) a{color: <?php echo $divi_ghost_df_text_color; ?> !important; }
#main-header ul#mobile_menu li.menu-item.current-menu-item:not(.marvel-menu-cta) a{color: <?php echo $divi_ghost_df_active_link_text_color; ?> !important; }
#main-header ul#mobile_menu li.menu-item.current-menu-ancestor:not(.marvel-menu-cta) > a{color: <?php echo $divi_ghost_df_active_link_text_color; ?> !important; }

#main-header .nav li ul.sub-menu,#main-header.et-fixed-header .nav li ul.sub-menu { background-color: <?php echo $divi_ghost_dropdown_menu_nav_bg; ?>;border-color:  <?php echo $divi_ghost_dropdown_line_nav_bg; ?>;}
#main-header ul#top-menu li.menu-item:not(.marvel-menu-cta) ul.sub-menu a{ color: <?php echo $divi_ghost_dropdown_text_nav_bg; ?> !important;}
<?php endif; ?>
</style>
									<?php
						  }
					}

			 }
		 } 
		 
		 if( in_array( 'authorp' , $ghost_selected_pages ) ){ 
							
				if ( is_author( ) || is_multi_author() ){
								$color_primary = et_get_option( 'color_primary', '#cda568' );
			$ghost_primary_nav_bg =  et_get_option( 'ghost_primary_nav_bg', '#f7af11' );
			$ghost_fixed_primary_nav_bg = et_get_option( 'ghost_fixed_primary_nav_bg', '#ffffff' );
								?>
<style id="ghost-customizer-css">
.normal.menu-item a:before{background-color: <?php echo $color_primary; ?>;}
<?php if($ghost_header): ?>
#main-header {background-color: <?php echo $ghost_primary_nav_bg; ?> !important; }		
#main-header.et-fixed-header {background-color: <?php echo $ghost_fixed_primary_nav_bg; ?> !important;}	

/*Search Text*/
#main-header .et_search_form_container input{color:<?php echo $divi_ghost_df_text_color; ?> !important;}
#main-header.et-fixed-header .et_search_form_container input{color:<?php echo $divi_ghost_fx_text_color; ?> !important;}
/*Form text color*/
#main-header .et-search-form input.et-search-field::-webkit-input-placeholder{color:<?php echo $divi_ghost_df_text_color; ?> !important;font-weight:500;}
#main-header .et-search-form input.et-search-field::-moz-placeholder{color:<?php echo $divi_ghost_df_text_color; ?> !important;font-weight:500;}
#main-header .et-search-form input.et-search-field:-ms-input-placeholder{ color:<?php echo $divi_ghost_df_text_color; ?> !important;font-weight:500;}
#main-header .et-search-form input.et-search-fieldl:-moz-placeholder{color:<?php echo $divi_ghost_df_text_color; ?> !important;font-weight:500;}

#main-header.et-fixed-header .et-search-form input.et-search-field::-webkit-input-placeholder{color:<?php echo $divi_ghost_fx_text_color; ?> !important;font-weight:500;}
#main-header.et-fixed-header .et-search-form input.et-search-field::-moz-placeholder{color:<?php echo $divi_ghost_fx_text_color; ?> !important;font-weight:500;}
#main-header.et-fixed-header .et-search-form input.et-search-field:-ms-input-placeholder{color:<?php echo $divi_ghost_fx_text_color; ?> !important;font-weight:500;}
#main-header.et-fixed-header .et-search-form input.et-search-fieldl:-moz-placeholder{color:<?php echo $divi_ghost_fx_text_color; ?> !important;font-weight:500;}

#main-header ul#top-menu li.menu-item:not(.marvel-menu-cta) a,#et_search_icon:before,span.et_close_search_field:after,#et-top-navigation .et-cart-info{color: <?php echo $divi_ghost_df_text_color; ?> !important; }
#main-header ul#top-menu li.menu-item.current-menu-item:not(.marvel-menu-cta) a{color: <?php echo $divi_ghost_df_active_link_text_color; ?> !important; }
#main-header ul#top-menu li.menu-item.current-menu-ancestor:not(.marvel-menu-cta) > a{color: <?php echo $divi_ghost_df_active_link_text_color; ?> !important; }

#main-header.et-fixed-header ul#top-menu li.menu-item:not(.marvel-menu-cta) a,#main-header.et-fixed-header #et_search_icon:before,#main-header.et-fixed-header span.et_close_search_field:after,#main-header.et-fixed-header #et-top-navigation .et-cart-info{color: <?php echo $divi_ghost_fx_text_color; ?> !important; }
#main-header.et-fixed-header ul#top-menu li.menu-item.current-menu-item:not(.marvel-menu-cta) a{color: <?php echo $divi_ghost_fx_active_link_text_color; ?> !important; }
#main-header.et-fixed-header ul#top-menu li.menu-item.current-menu-ancestor:not(.marvel-menu-cta) > a{color: <?php echo $divi_ghost_fx_active_link_text_color; ?> !important; }

#main-header ul#mobile_menu li.menu-item:not(.marvel-menu-cta) a{color: <?php echo $divi_ghost_df_text_color; ?> !important; }
#main-header ul#mobile_menu li.menu-item.current-menu-item:not(.marvel-menu-cta) a{color: <?php echo $divi_ghost_df_active_link_text_color; ?> !important; }
#main-header ul#mobile_menu li.menu-item.current-menu-ancestor:not(.marvel-menu-cta) > a{color: <?php echo $divi_ghost_df_active_link_text_color; ?> !important; }

#main-header .nav li ul.sub-menu,#main-header.et-fixed-header .nav li ul.sub-menu { background-color: <?php echo $divi_ghost_dropdown_menu_nav_bg; ?>;border-color:  <?php echo $divi_ghost_dropdown_line_nav_bg; ?>;}
#main-header ul#top-menu li.menu-item:not(.marvel-menu-cta) ul.sub-menu a{ color: <?php echo $divi_ghost_dropdown_text_nav_bg; ?> !important;}
<?php endif; ?>
</style>
		<?php				}
		 }
		 
		 if( in_array( 'searchp' , $ghost_selected_pages ) ){ 
							
				if ( is_search()  ){
					$color_primary = et_get_option( 'color_primary', '#cda568' );
			$ghost_primary_nav_bg =  et_get_option( 'ghost_primary_nav_bg', '#f7af11' );
			$ghost_fixed_primary_nav_bg = et_get_option( 'ghost_fixed_primary_nav_bg', '#ffffff' );
						?>
<style id="ghost-customizer-css">
.normal.menu-item a:before{background-color: <?php echo $color_primary; ?>;}
<?php if($ghost_header): ?>
#main-header {background-color: <?php echo $ghost_primary_nav_bg; ?> !important; }		
#main-header.et-fixed-header {background-color: <?php echo $ghost_fixed_primary_nav_bg; ?> !important;}

/*Search Text*/
#main-header .et_search_form_container input{color:<?php echo $divi_ghost_df_text_color; ?> !important;}
#main-header.et-fixed-header .et_search_form_container input{color:<?php echo $divi_ghost_fx_text_color; ?> !important;}
/*Form text color*/
#main-header .et-search-form input.et-search-field::-webkit-input-placeholder{color:<?php echo $divi_ghost_df_text_color; ?> !important;font-weight:500;}
#main-header .et-search-form input.et-search-field::-moz-placeholder{color:<?php echo $divi_ghost_df_text_color; ?> !important;font-weight:500;}
#main-header .et-search-form input.et-search-field:-ms-input-placeholder{ color:<?php echo $divi_ghost_df_text_color; ?> !important;font-weight:500;}
#main-header .et-search-form input.et-search-fieldl:-moz-placeholder{color:<?php echo $divi_ghost_df_text_color; ?> !important;font-weight:500;}

#main-header.et-fixed-header .et-search-form input.et-search-field::-webkit-input-placeholder{color:<?php echo $divi_ghost_fx_text_color; ?> !important;font-weight:500;}
#main-header.et-fixed-header .et-search-form input.et-search-field::-moz-placeholder{color:<?php echo $divi_ghost_fx_text_color; ?> !important;font-weight:500;}
#main-header.et-fixed-header .et-search-form input.et-search-field:-ms-input-placeholder{color:<?php echo $divi_ghost_fx_text_color; ?> !important;font-weight:500;}
#main-header.et-fixed-header .et-search-form input.et-search-fieldl:-moz-placeholder{color:<?php echo $divi_ghost_fx_text_color; ?> !important;font-weight:500;}

#main-header ul#top-menu li.menu-item:not(.marvel-menu-cta) a,#et_search_icon:before,span.et_close_search_field:after,#et-top-navigation .et-cart-info{color: <?php echo $divi_ghost_df_text_color; ?> !important; }
#main-header ul#top-menu li.menu-item.current-menu-item:not(.marvel-menu-cta) a{color: <?php echo $divi_ghost_df_active_link_text_color; ?> !important; }
#main-header ul#top-menu li.menu-item.current-menu-ancestor:not(.marvel-menu-cta) > a{color: <?php echo $divi_ghost_df_active_link_text_color; ?> !important; }

#main-header.et-fixed-header ul#top-menu li.menu-item:not(.marvel-menu-cta) a,#main-header.et-fixed-header #et_search_icon:before,#main-header.et-fixed-header span.et_close_search_field:after,#main-header.et-fixed-header #et-top-navigation .et-cart-info{color: <?php echo $divi_ghost_fx_text_color; ?> !important; }
#main-header.et-fixed-header ul#top-menu li.menu-item.current-menu-item:not(.marvel-menu-cta) a{color: <?php echo $divi_ghost_fx_active_link_text_color; ?> !important; }
#main-header.et-fixed-header ul#top-menu li.menu-item.current-menu-ancestor:not(.marvel-menu-cta) > a{color: <?php echo $divi_ghost_fx_active_link_text_color; ?> !important; }

#main-header ul#mobile_menu li.menu-item:not(.marvel-menu-cta) a{color: <?php echo $divi_ghost_df_text_color; ?> !important; }
#main-header ul#mobile_menu li.menu-item.current-menu-item:not(.marvel-menu-cta) a{color: <?php echo $divi_ghost_df_active_link_text_color; ?> !important; }
#main-header ul#mobile_menu li.menu-item.current-menu-ancestor:not(.marvel-menu-cta) > a{color: <?php echo $divi_ghost_df_active_link_text_color; ?> !important; }

#main-header .nav li ul.sub-menu,#main-header.et-fixed-header .nav li ul.sub-menu { background-color: <?php echo $divi_ghost_dropdown_menu_nav_bg; ?>;border-color:  <?php echo $divi_ghost_dropdown_line_nav_bg; ?>;}
#main-header ul#top-menu li.menu-item:not(.marvel-menu-cta) ul.sub-menu a{ color: <?php echo $divi_ghost_dropdown_text_nav_bg; ?> !important;}
<?php endif; ?>
</style>
						<?php
				}
		 }
		 
		  if( in_array( '404p' , $ghost_selected_pages ) ){ 
							
				if ( is_404()  ){
						$color_primary = et_get_option( 'color_primary', '#cda568' );
			$ghost_primary_nav_bg =  et_get_option( 'ghost_primary_nav_bg', '#f7af11' );
			$ghost_fixed_primary_nav_bg = et_get_option( 'ghost_fixed_primary_nav_bg', '#ffffff' );
						?>
<style id="ghost-customizer-css">
.normal.menu-item a:before{background-color: <?php echo $color_primary; ?>;}
<?php if($ghost_header): ?>
#main-header {background-color: <?php echo $ghost_primary_nav_bg; ?> !important; }		
#main-header.et-fixed-header {background-color: <?php echo $ghost_fixed_primary_nav_bg; ?> !important;}	

/*Search Text*/
#main-header .et_search_form_container input{color:<?php echo $divi_ghost_df_text_color; ?> !important;}
#main-header.et-fixed-header .et_search_form_container input{color:<?php echo $divi_ghost_fx_text_color; ?> !important;}
/*Form text color*/
#main-header .et-search-form input.et-search-field::-webkit-input-placeholder{color:<?php echo $divi_ghost_df_text_color; ?> !important;font-weight:500;}
#main-header .et-search-form input.et-search-field::-moz-placeholder{color:<?php echo $divi_ghost_df_text_color; ?> !important;font-weight:500;}
#main-header .et-search-form input.et-search-field:-ms-input-placeholder{ color:<?php echo $divi_ghost_df_text_color; ?> !important;font-weight:500;}
#main-header .et-search-form input.et-search-fieldl:-moz-placeholder{color:<?php echo $divi_ghost_df_text_color; ?> !important;font-weight:500;}

#main-header.et-fixed-header .et-search-form input.et-search-field::-webkit-input-placeholder{color:<?php echo $divi_ghost_fx_text_color; ?> !important;font-weight:500;}
#main-header.et-fixed-header .et-search-form input.et-search-field::-moz-placeholder{color:<?php echo $divi_ghost_fx_text_color; ?> !important;font-weight:500;}
#main-header.et-fixed-header .et-search-form input.et-search-field:-ms-input-placeholder{color:<?php echo $divi_ghost_fx_text_color; ?> !important;font-weight:500;}
#main-header.et-fixed-header .et-search-form input.et-search-fieldl:-moz-placeholder{color:<?php echo $divi_ghost_fx_text_color; ?> !important;font-weight:500;}

#main-header ul#top-menu li.menu-item:not(.marvel-menu-cta) a,#et_search_icon:before,span.et_close_search_field:after,#et-top-navigation .et-cart-info{color: <?php echo $divi_ghost_df_text_color; ?> !important; }
#main-header ul#top-menu li.menu-item.current-menu-item:not(.marvel-menu-cta) a{color: <?php echo $divi_ghost_df_active_link_text_color; ?> !important; }
#main-header ul#top-menu li.menu-item.current-menu-ancestor:not(.marvel-menu-cta) > a{color: <?php echo $divi_ghost_df_active_link_text_color; ?> !important; }

#main-header.et-fixed-header ul#top-menu li.menu-item:not(.marvel-menu-cta) a,#main-header.et-fixed-header #et_search_icon:before,#main-header.et-fixed-header span.et_close_search_field:after,#main-header.et-fixed-header #et-top-navigation .et-cart-info{color: <?php echo $divi_ghost_fx_text_color; ?> !important; }
#main-header.et-fixed-header ul#top-menu li.menu-item.current-menu-item:not(.marvel-menu-cta) a{color: <?php echo $divi_ghost_fx_active_link_text_color; ?> !important; }
#main-header.et-fixed-header ul#top-menu li.menu-item.current-menu-ancestor:not(.marvel-menu-cta) > a{color: <?php echo $divi_ghost_fx_active_link_text_color; ?> !important; }

#main-header ul#mobile_menu li.menu-item:not(.marvel-menu-cta) a{color: <?php echo $divi_ghost_df_text_color; ?> !important; }
#main-header ul#mobile_menu li.menu-item.current-menu-item:not(.marvel-menu-cta) a{color: <?php echo $divi_ghost_df_active_link_text_color; ?> !important; }
#main-header ul#mobile_menu li.menu-item.current-menu-ancestor:not(.marvel-menu-cta) > a{color: <?php echo $divi_ghost_df_active_link_text_color; ?> !important; }

#main-header .nav li ul.sub-menu,#main-header.et-fixed-header .nav li ul.sub-menu { background-color: <?php echo $divi_ghost_dropdown_menu_nav_bg; ?>;border-color:  <?php echo $divi_ghost_dropdown_line_nav_bg; ?>;}
#main-header ul#top-menu li.menu-item:not(.marvel-menu-cta) ul.sub-menu a{ color: <?php echo $divi_ghost_dropdown_text_nav_bg; ?> !important;}
<?php endif; ?>
</style>
						<?php
				}
		  }
					
	 
	 	  if( in_array( 'datep' , $ghost_selected_pages ) ){ 
							
				if ( is_date()  || is_year() || is_month()  || is_day()  || is_time() ){
						$color_primary = et_get_option( 'color_primary', '#cda568' );
			$ghost_primary_nav_bg =  et_get_option( 'ghost_primary_nav_bg', '#f7af11' );
			$ghost_fixed_primary_nav_bg = et_get_option( 'ghost_fixed_primary_nav_bg', '#ffffff' );
						?>
<style id="ghost-customizer-css">
.normal.menu-item a:before{background-color: <?php echo $color_primary; ?>;}
<?php if($ghost_header): ?>
#main-header {background-color: <?php echo $ghost_primary_nav_bg; ?> !important; }		
#main-header.et-fixed-header {background-color: <?php echo $ghost_fixed_primary_nav_bg; ?> !important;}

/*Search Text*/
#main-header .et_search_form_container input{color:<?php echo $divi_ghost_df_text_color; ?> !important;}
#main-header.et-fixed-header .et_search_form_container input{color:<?php echo $divi_ghost_fx_text_color; ?> !important;}
/*Form text color*/
#main-header .et-search-form input.et-search-field::-webkit-input-placeholder{color:<?php echo $divi_ghost_df_text_color; ?> !important;font-weight:500;}
#main-header .et-search-form input.et-search-field::-moz-placeholder{color:<?php echo $divi_ghost_df_text_color; ?> !important;font-weight:500;}
#main-header .et-search-form input.et-search-field:-ms-input-placeholder{ color:<?php echo $divi_ghost_df_text_color; ?> !important;font-weight:500;}
#main-header .et-search-form input.et-search-fieldl:-moz-placeholder{color:<?php echo $divi_ghost_df_text_color; ?> !important;font-weight:500;}

#main-header.et-fixed-header .et-search-form input.et-search-field::-webkit-input-placeholder{color:<?php echo $divi_ghost_fx_text_color; ?> !important;font-weight:500;}
#main-header.et-fixed-header .et-search-form input.et-search-field::-moz-placeholder{color:<?php echo $divi_ghost_fx_text_color; ?> !important;font-weight:500;}
#main-header.et-fixed-header .et-search-form input.et-search-field:-ms-input-placeholder{color:<?php echo $divi_ghost_fx_text_color; ?> !important;font-weight:500;}
#main-header.et-fixed-header .et-search-form input.et-search-fieldl:-moz-placeholder{color:<?php echo $divi_ghost_fx_text_color; ?> !important;font-weight:500;}

#main-header ul#top-menu li.menu-item:not(.marvel-menu-cta) a,#et_search_icon:before,span.et_close_search_field:after,#et-top-navigation .et-cart-info{color: <?php echo $divi_ghost_df_text_color; ?> !important; }
#main-header ul#top-menu li.menu-item.current-menu-item:not(.marvel-menu-cta) a{color: <?php echo $divi_ghost_df_active_link_text_color; ?> !important; }
#main-header ul#top-menu li.menu-item.current-menu-ancestor:not(.marvel-menu-cta) > a{color: <?php echo $divi_ghost_df_active_link_text_color; ?> !important; }

#main-header.et-fixed-header ul#top-menu li.menu-item:not(.marvel-menu-cta) a,#main-header.et-fixed-header #et_search_icon:before,#main-header.et-fixed-header span.et_close_search_field:after,#main-header.et-fixed-header #et-top-navigation .et-cart-info{color: <?php echo $divi_ghost_fx_text_color; ?> !important; }
#main-header.et-fixed-header ul#top-menu li.menu-item.current-menu-item:not(.marvel-menu-cta) a{color: <?php echo $divi_ghost_fx_active_link_text_color; ?> !important; }
#main-header.et-fixed-header ul#top-menu li.menu-item.current-menu-ancestor:not(.marvel-menu-cta) > a{color: <?php echo $divi_ghost_fx_active_link_text_color; ?> !important; }

#main-header ul#mobile_menu li.menu-item:not(.marvel-menu-cta) a{color: <?php echo $divi_ghost_df_text_color; ?> !important; }
#main-header ul#mobile_menu li.menu-item.current-menu-item:not(.marvel-menu-cta) a{color: <?php echo $divi_ghost_df_active_link_text_color; ?> !important; }
#main-header ul#mobile_menu li.menu-item.current-menu-ancestor:not(.marvel-menu-cta) > a{color: <?php echo $divi_ghost_df_active_link_text_color; ?> !important; }

#main-header .nav li ul.sub-menu,#main-header.et-fixed-header .nav li ul.sub-menu { background-color: <?php echo $divi_ghost_dropdown_menu_nav_bg; ?>;border-color:  <?php echo $divi_ghost_dropdown_line_nav_bg; ?>;}
#main-header ul#top-menu li.menu-item:not(.marvel-menu-cta) ul.sub-menu a{ color: <?php echo $divi_ghost_dropdown_text_nav_bg; ?> !important;}
<?php endif; ?>
</style>
						<?php 
				}
		 }
		
		 
	}
	
	}//end if
}

add_action( 'add_meta_boxes',  'ghost_header_meta_box' ); 
add_action( 'save_post', 'ghost_header_save_meta_box_data' );
function ghost_header_meta_box() 
{
		$ghost_header = et_get_option( 'ghost_header', true );
		if ( $ghost_header == 1 ){
			foreach(get_post_types() as $pt) {
				if ( post_type_supports($pt, 'editor') ){
						add_meta_box( 'ghost_header_meta_box', esc_html__( 'Ghost Header Settings', 'Divi' ), 'b3_ghost_header_meta_box', $pt , 'side', 'high' );
				}
			}
		}
		
}
		
function b3_ghost_header_meta_box($post){
$ghost_header_enable = get_post_meta( $post->ID, 'ghost_header_enable', true );

?>
<p class="et_pb_page_settings ghost_header_enable_settings" >
		<label for="ghost_header_enable" style="display: block; font-weight: bold; margin-bottom: 5px;"><?php esc_html_e( 'Ghost Header', 'Divi' ); ?>: </label>

		<select id="ghost_header_enable" name="ghost_header_enable">
			<option value="Default" <?php selected( 'Default', $ghost_header_enable ); ?>><?php esc_html_e( 'Default', 'Divi' ); ?></option>
			<option value="on" <?php selected( 'on', $ghost_header_enable ); ?>><?php esc_html_e( 'Yes', 'Divi' ); ?></option>
			<option value="off" <?php selected( 'off', $ghost_header_enable ); ?>><?php esc_html_e( 'No', 'Divi' ); ?></option>
			
		</select>
</p>
<?php 
}

function ghost_header_save_meta_box_data($post_id){
$ghost_header = et_get_option( 'ghost_header', true );
if ( $ghost_header == 1 ){	
				
		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
					return;
		}
		if ( isset( $_POST['post_type'] ) && 'page' == $_POST['post_type'] )
		{
			if ( ! current_user_can( 'edit_page', $post_id ) ) {
				return;
			}
		} 
		else 
		{
			if ( ! current_user_can( 'edit_post', $post_id ) ) {
				return;
			}
		}
		$ghost_header_enable = sanitize_text_field( $_POST['ghost_header_enable'] );
			
		// Update the meta field in the database.
		update_post_meta( $post_id, 'ghost_header_enable', $ghost_header_enable );
}
}
?>